=============
feincms3-meta
=============

.. image:: https://github.com/matthiask/feincms3-meta/actions/workflows/tests.yml/badge.svg
    :target: https://github.com/matthiask/feincms3-meta/
    :alt: CI Status

Helpers and mixins for making meta and `open graph <http://ogp.me/>`__
tags less annoying.

Documentation is available as a part of `feincms3
<https://feincms3.readthedocs.io/>`__'s documentation.

The guide is here: `Meta and OpenGraph tags
<https://feincms3.readthedocs.io/en/latest/guides/meta-opengraph-tags.html>`__
The guide's title

Despite its name and the fact that it is documented as a part of
feincms3, feincms3-meta can also be used standalone.
